@@ -9,7 +9,12 @@ from webargs.flaskparser import abort, parser
 from werkzeug.exceptions import HTTPException
 from werkzeug.routing import BaseConverter, ValidationError
 
-from relay.api.resources import TrustlineEvents
+from relay.api.resources import (
+    TotalTransferredSum,
+    TrustlineEvents,
+    UserDebtsLists,
+    UserEarnedMediationFeesList,
+)
 
 from .exchange.resources import (
     EventsExchange,
@@ -121,6 +126,11 @@ def ApiApp(trustlines, *, enabled_apis):
             "/networks/<address:network_address>/users/<address:user_address>/"
             "interests/<address:counterparty_address>",
         )
+        add_resource(
+            UserEarnedMediationFeesList,
+            "/networks/<address:network_address>/users/<address:user_address>/"
+            "mediation-fees",
+        )
         add_resource(TransferInformation, "/transfers")
         add_resource(AppliedDelegationFees, "/delegation-fees/")
         add_resource(
@@ -151,6 +161,12 @@ def ApiApp(trustlines, *, enabled_apis):
         add_resource(TransactionInfos, "/users/<address:user_address>/txinfos")
         add_resource(Balance, "/users/<address:user_address>/balance")
         add_resource(UserTrustlines, "/users/<address:user_address>/trustlines")
+        add_resource(UserDebtsLists, "/users/<address:user_address>/debts")
+        add_resource(
+            TotalTransferredSum,
+            "/networks/<address:network_address>/users/<address:sender_address>/"
+            "transferredSums/<address:receiver_address>",
+        )
 
         api_bp.add_url_rule(
             "/networks/<address:network_address>/image",
